@@ -10,6 +10,7 @@ import (
 	"github.com/miguelmota/cointop/pkg/chartplot"
 	"github.com/miguelmota/cointop/pkg/timeutil"
 	"github.com/miguelmota/cointop/pkg/ui"
+	log "github.com/sirupsen/logrus"
 )
 
 // ChartView is structure for chart view
@@ -58,7 +59,7 @@ func ChartRangesMap() map[string]time.Duration {
 
 // UpdateChart updates the chart view
 func (ct *Cointop) UpdateChart() error {
-	ct.debuglog("UpdateChart()")
+	log.Debug("UpdateChart()")
 	chartLock.Lock()
 	defer chartLock.Unlock()
 
@@ -97,7 +98,7 @@ func (ct *Cointop) UpdateChart() error {
 
 // ChartPoints calculates the the chart points
 func (ct *Cointop) ChartPoints(symbol string, name string) error {
-	ct.debuglog("ChartPoints()")
+	log.Debug("ChartPoints()")
 	maxX := ct.ChartWidth()
 
 	chartPointsLock.Lock()
@@ -132,7 +133,7 @@ func (ct *Cointop) ChartPoints(symbol string, name string) error {
 	if found {
 		// cache hit
 		data, _ = cached.([]float64)
-		ct.debuglog("ct.ChartPoints() soft cache hit")
+		log.Debug("ChartPoints() soft cache hit")
 	}
 
 	if len(data) == 0 {
@@ -178,7 +179,7 @@ func (ct *Cointop) ChartPoints(symbol string, name string) error {
 
 // PortfolioChart renders the portfolio chart
 func (ct *Cointop) PortfolioChart() error {
-	ct.debuglog("PortfolioChart()")
+	log.Debug("PortfolioChart()")
 	maxX := ct.ChartWidth()
 	chartPointsLock.Lock()
 	defer chartPointsLock.Unlock()
@@ -189,8 +190,10 @@ func (ct *Cointop) PortfolioChart() error {
 	chart := chartplot.NewChartPlot()
 	chart.SetHeight(ct.State.chartHeight)
 
-	rangeseconds := ct.chartRangesMap[ct.State.selectedChartRange]
-	if ct.State.selectedChartRange == "YTD" {
+	convert := ct.State.currencyConversion            // cache here
+	selectedChartRange := ct.State.selectedChartRange // cache here
+	rangeseconds := ct.chartRangesMap[selectedChartRange]
+	if selectedChartRange == "YTD" {
 		ytd := time.Now().Unix() - int64(timeutil.BeginningOfYear().Unix())
 		rangeseconds = time.Duration(ytd) * time.Second
 	}
@@ -216,12 +219,12 @@ func (ct *Cointop) PortfolioChart() error {
 		}
 
 		var graphData []float64
-		cachekey := strings.ToLower(fmt.Sprintf("%s_%s", p.Symbol, strings.Replace(ct.State.selectedChartRange, " ", "", -1)))
+		cachekey := strings.ToLower(fmt.Sprintf("%s_%s_%s", p.Symbol, convert, strings.Replace(selectedChartRange, " ", "", -1)))
 		cached, found := ct.cache.Get(cachekey)
 		if found {
 			// cache hit
 			graphData, _ = cached.([]float64)
-			ct.debuglog("soft cache hit")
+			log.Debug("PortfolioChart() soft cache hit")
 		} else {
 			if ct.filecache != nil {
 				ct.filecache.Get(cachekey, &graphData)
@@ -230,7 +233,6 @@ func (ct *Cointop) PortfolioChart() error {
 			if len(graphData) == 0 {
 				time.Sleep(2 * time.Second)
 
-				convert := ct.State.currencyConversion
 				apiGraphData, err := ct.api.GetCoinGraphData(convert, p.Symbol, p.Name, start, end)
 				if err != nil {
 					return err
@@ -272,7 +274,7 @@ func (ct *Cointop) PortfolioChart() error {
 
 // ShortenChart decreases the chart height by one row
 func (ct *Cointop) ShortenChart() error {
-	ct.debuglog("ShortenChart()")
+	log.Debug("ShortenChart()")
 	candidate := ct.State.chartHeight - 1
 	if candidate < 5 {
 		return nil
@@ -286,7 +288,7 @@ func (ct *Cointop) ShortenChart() error {
 
 // EnlargeChart increases the chart height by one row
 func (ct *Cointop) EnlargeChart() error {
-	ct.debuglog("EnlargeChart()")
+	log.Debug("EnlargeChart()")
 	candidate := ct.State.lastChartHeight + 1
 	if candidate > 30 {
 		return nil
@@ -300,7 +302,7 @@ func (ct *Cointop) EnlargeChart() error {
 
 // NextChartRange sets the chart to the next range option
 func (ct *Cointop) NextChartRange() error {
-	ct.debuglog("NextChartRange()")
+	log.Debug("NextChartRange()")
 	sel := 0
 	max := len(ct.chartRanges)
 	for i, k := range ct.chartRanges {
@@ -321,7 +323,7 @@ func (ct *Cointop) NextChartRange() error {
 
 // PrevChartRange sets the chart to the prevous range option
 func (ct *Cointop) PrevChartRange() error {
-	ct.debuglog("PrevChartRange()")
+	log.Debug("PrevChartRange()")
 	sel := 0
 	for i, k := range ct.chartRanges {
 		if k == ct.State.selectedChartRange {
@@ -340,7 +342,7 @@ func (ct *Cointop) PrevChartRange() error {
 
 // FirstChartRange sets the chart to the first range option
 func (ct *Cointop) FirstChartRange() error {
-	ct.debuglog("FirstChartRange()")
+	log.Debug("FirstChartRange()")
 	ct.State.selectedChartRange = ct.chartRanges[0]
 	go ct.UpdateChart()
 	return nil
@@ -348,7 +350,7 @@ func (ct *Cointop) FirstChartRange() error {
 
 // LastChartRange sets the chart to the last range option
 func (ct *Cointop) LastChartRange() error {
-	ct.debuglog("LastChartRange()")
+	log.Debug("LastChartRange()")
 	ct.State.selectedChartRange = ct.chartRanges[len(ct.chartRanges)-1]
 	go ct.UpdateChart()
 	return nil
@@ -356,7 +358,7 @@ func (ct *Cointop) LastChartRange() error {
 
 // ToggleCoinChart toggles between the global chart and the coin chart
 func (ct *Cointop) ToggleCoinChart() error {
-	ct.debuglog("ToggleCoinChart()")
+	log.Debug("ToggleCoinChart()")
 	highlightedcoin := ct.HighlightedRowCoin()
 	if ct.State.selectedCoin == highlightedcoin {
 		ct.State.selectedCoin = nil
@@ -378,7 +380,7 @@ func (ct *Cointop) ToggleCoinChart() error {
 
 // ShowChartLoader shows chart loading indicator
 func (ct *Cointop) ShowChartLoader() error {
-	ct.debuglog("ShowChartLoader()")
+	log.Debug("ShowChartLoader()")
 	ct.UpdateUI(func() error {
 		content := "\n\nLoading..."
 		return ct.Views.Chart.Update(ct.colorscheme.Chart(content))
@@ -389,8 +391,8 @@ func (ct *Cointop) ShowChartLoader() error {
 
 // ChartWidth returns the width for chart
 func (ct *Cointop) ChartWidth() int {
-	ct.debuglog("chartWidth()")
-	w := ct.width()
+	log.Debug("ChartWidth()")
+	w := ct.Width()
 	max := 175
 	if w > max {
 		return max
@@ -401,7 +403,7 @@ func (ct *Cointop) ChartWidth() int {
 
 // ToggleChartFullscreen toggles the chart fullscreen mode
 func (ct *Cointop) ToggleChartFullscreen() error {
-	ct.debuglog("ToggleChartFullscreen()")
+	log.Debug("ToggleChartFullscreen()")
 	ct.State.onlyChart = !ct.State.onlyChart
 	ct.State.onlyTable = false
 	if !ct.State.onlyChart {
