@@ -19,6 +19,7 @@ var SupportedCoinTableHeaders = []string{
 	"24h_change",
 	"7d_change",
 	"30d_change",
+	"1y_change",
 	"24h_volume",
 	"market_cap",
 	"available_supply",
@@ -59,7 +60,7 @@ func (ct *Cointop) GetCoinsTableHeaders() []string {
 
 // GetCoinsTable returns the table for diplaying the coins
 func (ct *Cointop) GetCoinsTable() *table.Table {
-	maxX := ct.width()
+	maxX := ct.Width()
 	t := table.NewTable().SetWidth(maxX)
 	var rows [][]*table.RowCell
 	headers := ct.GetCoinsTableHeaders()
@@ -221,6 +222,25 @@ func (ct *Cointop) GetCoinsTable() *table.Table {
 						Color:       color30d,
 						Text:        text,
 					})
+			case "1y_change":
+				color1y := ct.colorscheme.TableColumnChange
+				if coin.PercentChange1Y > 0 {
+					color1y = ct.colorscheme.TableColumnChangeUp
+				}
+				if coin.PercentChange1Y < 0 {
+					color1y = ct.colorscheme.TableColumnChangeDown
+				}
+				text := fmt.Sprintf("%v%%", humanize.Numericf(coin.PercentChange1Y, 2))
+				ct.SetTableColumnWidthFromString(header, text)
+				ct.SetTableColumnAlignLeft(header, false)
+				rowCells = append(rowCells,
+					&table.RowCell{
+						LeftMargin:  leftMargin,
+						RightMargin: rightMargin,
+						LeftAlign:   false,
+						Color:       color1y,
+						Text:        text,
+					})
 			case "market_cap":
 				text := humanize.Monetaryf(coin.MarketCap, 0)
 				ct.SetTableColumnWidthFromString(header, text)
