@@ -17,6 +17,7 @@ import (
 	"github.com/miguelmota/cointop/pkg/table"
 	"github.com/miguelmota/cointop/pkg/ui"
 	"github.com/miguelmota/gocui"
+	log "github.com/sirupsen/logrus"
 )
 
 // TODO: clean up and optimize codebase
@@ -56,6 +57,7 @@ type State struct {
 	hideChart                  bool
 	hideTable                  bool
 	hideStatusbar              bool
+	hidePortfolioBalances      bool
 	keepRowFocusOnSort         bool
 	lastSelectedRowIndex       int
 	marketBarHeight            int
@@ -95,7 +97,7 @@ type Cointop struct {
 	apiKeys         *APIKeys
 	cache           *cache.Cache
 	colorsDir       string
-	config          config // toml config
+	config          ConfigFileConfig
 	configFilepath  string
 	api             api.Interface
 	apiChoice       string
@@ -103,7 +105,6 @@ type Cointop struct {
 	chartRangesMap  map[string]time.Duration
 	colorschemeName string
 	colorscheme     *Colorscheme
-	debug           bool
 	filecache       *filecache.FileCache
 	logfile         *os.File
 	forceRefresh    chan bool
@@ -147,23 +148,24 @@ type PriceAlerts struct {
 
 // Config config options
 type Config struct {
-	APIChoice           string
-	CacheDir            string
-	ColorsDir           string
-	Colorscheme         string
-	ConfigFilepath      string
-	CoinMarketCapAPIKey string
-	NoPrompts           bool
-	HideMarketbar       bool
-	HideChart           bool
-	HideTable           bool
-	HideStatusbar       bool
-	NoCache             bool
-	OnlyTable           bool
-	OnlyChart           bool
-	RefreshRate         *uint
-	PerPage             uint
-	MaxPages            uint
+	APIChoice             string
+	CacheDir              string
+	ColorsDir             string
+	Colorscheme           string
+	ConfigFilepath        string
+	CoinMarketCapAPIKey   string
+	NoPrompts             bool
+	HideMarketbar         bool
+	HideChart             bool
+	HideTable             bool
+	HideStatusbar         bool
+	HidePortfolioBalances bool
+	NoCache               bool
+	OnlyTable             bool
+	OnlyChart             bool
+	RefreshRate           *uint
+	PerPage               uint
+	MaxPages              uint
 }
 
 // APIKeys is api keys structure
@@ -200,9 +202,8 @@ var DefaultColorsDir = fmt.Sprintf("%s/colors", DefaultConfigFilepath)
 
 // NewCointop initializes cointop
 func NewCointop(config *Config) (*Cointop, error) {
-	var debug bool
 	if os.Getenv("DEBUG") != "" {
-		debug = true
+		log.SetLevel(log.DebugLevel)
 	}
 
 	if config == nil {
@@ -235,7 +236,6 @@ func NewCointop(config *Config) (*Cointop, error) {
 		colorsDir:      config.ColorsDir,
 		configFilepath: configFilepath,
 		chartRanges:    ChartRanges(),
-		debug:          debug,
 		chartRangesMap: ChartRangesMap(),
 		limiter:        time.NewTicker(2 * time.Second).C,
 		filecache:      nil,
@@ -253,6 +253,7 @@ func NewCointop(config *Config) (*Cointop, error) {
 			hideChart:             config.HideChart,
 			hideTable:             config.HideTable,
 			hideStatusbar:         config.HideStatusbar,
+			hidePortfolioBalances: config.HidePortfolioBalances,
 			keepRowFocusOnSort:    false,
 			marketBarHeight:       1,
 			maxPages:              int(maxPages),
@@ -289,9 +290,7 @@ func NewCointop(config *Config) (*Cointop, error) {
 			Input:       NewInputView(),
 		},
 	}
-	if debug {
-		ct.initlog()
-	}
+	ct.initlog()
 
 	err := ct.SetupConfig()
 	if err != nil {
@@ -352,7 +351,7 @@ func NewCointop(config *Config) (*Cointop, error) {
 		ct.colorschemeName = config.Colorscheme
 	}
 
-	colors, err := ct.getColorschemeColors()
+	colors, err := ct.GetColorschemeColors()
 	if err != nil {
 		return nil, err
 	}
@@ -470,7 +469,7 @@ func NewCointop(config *Config) (*Cointop, error) {
 
 // Run runs cointop
 func (ct *Cointop) Run() error {
-	ct.debuglog("run()")
+	log.Debug("Run()")
 	ui, err := ui.NewUI()
 	if err != nil {
 		return err
@@ -486,7 +485,7 @@ func (ct *Cointop) Run() error {
 	ui.SetMouse(true)
 	ui.SetHighlight(true)
 	ui.SetManagerFunc(ct.layout)
-	if err := ct.Keybindings(ct.g); err != nil {
+	if err := ct.SetKeybindings(); err != nil {
 		return fmt.Errorf("keybindings: %v", err)
 	}
 
@@ -574,7 +573,7 @@ func Reset(config *ResetConfig) error {
 
 	configDeleted := false
 
-	for _, configPath := range possibleConfigPaths {
+	for _, configPath := range PossibleConfigPaths {
 		normalizedPath := pathutil.NormalizePath(configPath)
 		if _, err := os.Stat(normalizedPath); !os.IsNotExist(err) {
 			if config.Log {
