@@ -14,15 +14,18 @@ import (
 
 	"github.com/miguelmota/cointop/pkg/pathutil"
 	"github.com/miguelmota/cointop/pkg/toml"
+	log "github.com/sirupsen/logrus"
 )
 
-var fileperm = os.FileMode(0644)
+// FilePerm is the default file permissions
+var FilePerm = os.FileMode(0644)
 
 // ErrInvalidPriceAlert is error for invalid price alert value
 var ErrInvalidPriceAlert = errors.New("invalid price alert value")
 
+// PossibleConfigPaths are the the possible config file paths.
 // NOTE: this is to support previous default config filepaths
-var possibleConfigPaths = []string{
+var PossibleConfigPaths = []string{
 	":PREFERRED_CONFIG_HOME:/cointop/config.toml",
 	":HOME:/.config/cointop/config.toml",
 	":HOME:/.config/cointop/config",
@@ -30,7 +33,8 @@ var possibleConfigPaths = []string{
 	":HOME:/.cointop/config.toml",
 }
 
-type config struct {
+// ConfigFileConfig is the config file structure
+type ConfigFileConfig struct {
 	Shortcuts         map[string]interface{} `toml:"shortcuts"`
 	Favorites         map[string]interface{} `toml:"favorites"`
 	Portfolio         map[string]interface{} `toml:"portfolio"`
@@ -48,11 +52,11 @@ type config struct {
 
 // SetupConfig loads config file
 func (ct *Cointop) SetupConfig() error {
-	ct.debuglog("setupConfig()")
+	log.Debug("SetupConfig()")
 	if err := ct.CreateConfigIfNotExists(); err != nil {
 		return err
 	}
-	if err := ct.parseConfig(); err != nil {
+	if err := ct.ParseConfig(); err != nil {
 		return err
 	}
 	if err := ct.loadTableConfig(); err != nil {
@@ -100,13 +104,13 @@ func (ct *Cointop) SetupConfig() error {
 
 // CreateConfigIfNotExists creates config file if it doesn't exist
 func (ct *Cointop) CreateConfigIfNotExists() error {
-	ct.debuglog("createConfigIfNotExists()")
+	log.Debug("CreateConfigIfNotExists()")
 
 	ct.configFilepath = pathutil.NormalizePath(ct.configFilepath)
 
 	// check if config file exists in one of th default paths
 	if ct.configFilepath == DefaultConfigFilepath {
-		for _, configPath := range possibleConfigPaths {
+		for _, configPath := range PossibleConfigPaths {
 			normalizedPath := pathutil.NormalizePath(configPath)
 			if _, err := os.Stat(normalizedPath); err == nil {
 				ct.configFilepath = normalizedPath
@@ -115,12 +119,12 @@ func (ct *Cointop) CreateConfigIfNotExists() error {
 		}
 	}
 
-	err := ct.makeConfigDir()
+	err := ct.MakeConfigDir()
 	if err != nil {
 		return err
 	}
 
-	err = ct.makeConfigFile()
+	err = ct.MakeConfigFile()
 	if err != nil {
 		return err
 	}
@@ -130,7 +134,7 @@ func (ct *Cointop) CreateConfigIfNotExists() error {
 
 // ConfigDirPath returns the config directory path
 func (ct *Cointop) ConfigDirPath() string {
-	ct.debuglog("configDirPath()")
+	log.Debug("ConfigDirPath()")
 	path := pathutil.NormalizePath(ct.configFilepath)
 	separator := string(filepath.Separator)
 	parts := strings.Split(path, separator)
@@ -139,13 +143,13 @@ func (ct *Cointop) ConfigDirPath() string {
 
 // ConfigFilePath return the config file path
 func (ct *Cointop) ConfigFilePath() string {
-	ct.debuglog("configFilePath()")
+	log.Debug("ConfigFilePath()")
 	return pathutil.NormalizePath(ct.configFilepath)
 }
 
 // ConfigPath return the config file path
-func (ct *Cointop) makeConfigDir() error {
-	ct.debuglog("makeConfigDir()")
+func (ct *Cointop) MakeConfigDir() error {
+	log.Debug("MakeConfigDir()")
 	path := ct.ConfigDirPath()
 	if _, err := os.Stat(path); os.IsNotExist(err) {
 		return os.MkdirAll(path, os.ModePerm)
@@ -155,8 +159,8 @@ func (ct *Cointop) makeConfigDir() error {
 }
 
 // MakeConfigFile creates a new config file
-func (ct *Cointop) makeConfigFile() error {
-	ct.debuglog("makeConfigFile()")
+func (ct *Cointop) MakeConfigFile() error {
+	log.Debug("MakeConfigFile()")
 	path := ct.ConfigFilePath()
 	if _, err := os.Stat(path); os.IsNotExist(err) {
 		fo, err := os.Create(path)
@@ -164,7 +168,7 @@ func (ct *Cointop) makeConfigFile() error {
 			return err
 		}
 		defer fo.Close()
-		b, err := ct.configToToml()
+		b, err := ct.ConfigToToml()
 		if err != nil {
 			return err
 		}
@@ -177,16 +181,16 @@ func (ct *Cointop) makeConfigFile() error {
 
 // SaveConfig writes settings to the config file
 func (ct *Cointop) SaveConfig() error {
-	ct.debuglog("saveConfig()")
+	log.Debug("SaveConfig()")
 	ct.saveMux.Lock()
 	defer ct.saveMux.Unlock()
 	path := ct.ConfigFilePath()
 	if _, err := os.Stat(path); err == nil {
-		b, err := ct.configToToml()
+		b, err := ct.ConfigToToml()
 		if err != nil {
 			return err
 		}
-		err = ioutil.WriteFile(path, b, fileperm)
+		err = ioutil.WriteFile(path, b, FilePerm)
 		if err != nil {
 			return err
 		}
@@ -195,9 +199,9 @@ func (ct *Cointop) SaveConfig() error {
 }
 
 // ParseConfig decodes the toml config file
-func (ct *Cointop) parseConfig() error {
-	ct.debuglog("parseConfig()")
-	var conf config
+func (ct *Cointop) ParseConfig() error {
+	log.Debug("ParseConfig()")
+	var conf ConfigFileConfig
 	path := ct.configFilepath
 	if _, err := toml.DecodeFile(path, &conf); err != nil {
 		return err
@@ -208,8 +212,8 @@ func (ct *Cointop) parseConfig() error {
 }
 
 // ConfigToToml encodes config struct to TOML
-func (ct *Cointop) configToToml() ([]byte, error) {
-	ct.debuglog("configToToml()")
+func (ct *Cointop) ConfigToToml() ([]byte, error) {
+	log.Debug("ConfigToToml()")
 	shortcutsIfcs := map[string]interface{}{}
 	for k, v := range ct.State.shortcutKeys {
 		var i interface{} = v
@@ -293,7 +297,7 @@ func (ct *Cointop) configToToml() ([]byte, error) {
 	var keepRowFocusOnSortIfc interface{} = ct.State.keepRowFocusOnSort
 	tableMapIfc["keep_row_focus_on_sort"] = keepRowFocusOnSortIfc
 
-	var inputs = &config{
+	var inputs = &ConfigFileConfig{
 		API:               apiChoiceIfc,
 		Colorscheme:       colorschemeIfc,
 		CoinMarketCap:     cmcIfc,
@@ -321,6 +325,7 @@ func (ct *Cointop) configToToml() ([]byte, error) {
 
 // LoadTableConfig loads table config from toml config into state struct
 func (ct *Cointop) loadTableConfig() error {
+	log.Debug("loadTableConfig()")
 	err := ct.loadTableColumnsFromConfig()
 	if err != nil {
 		return err
@@ -335,7 +340,7 @@ func (ct *Cointop) loadTableConfig() error {
 
 // LoadTableColumnsFromConfig loads preferred coins table columns from config file to struct
 func (ct *Cointop) loadTableColumnsFromConfig() error {
-	ct.debuglog("loadTableColumnsFromConfig()")
+	log.Debug("loadTableColumnsFromConfig()")
 	columnsIfc, ok := ct.config.Table["columns"]
 	if !ok {
 		return nil
@@ -361,7 +366,7 @@ func (ct *Cointop) loadTableColumnsFromConfig() error {
 
 // LoadShortcutsFromConfig loads keyboard shortcuts from config file to struct
 func (ct *Cointop) loadShortcutsFromConfig() error {
-	ct.debuglog("loadShortcutsFromConfig()")
+	log.Debug("loadShortcutsFromConfig()")
 	for k, ifc := range ct.config.Shortcuts {
 		if v, ok := ifc.(string); ok {
 			if !ct.ActionExists(v) {
@@ -375,7 +380,7 @@ func (ct *Cointop) loadShortcutsFromConfig() error {
 
 // LoadCurrencyFromConfig loads currency from config file to struct
 func (ct *Cointop) loadCurrencyFromConfig() error {
-	ct.debuglog("loadCurrencyFromConfig()")
+	log.Debug("loadCurrencyFromConfig()")
 	if currency, ok := ct.config.Currency.(string); ok {
 		ct.State.currencyConversion = strings.ToUpper(currency)
 	}
@@ -384,7 +389,7 @@ func (ct *Cointop) loadCurrencyFromConfig() error {
 
 // LoadDefaultViewFromConfig loads default view from config file to struct
 func (ct *Cointop) loadDefaultViewFromConfig() error {
-	ct.debuglog("loadDefaultViewFromConfig()")
+	log.Debug("loadDefaultViewFromConfig()")
 	if defaultView, ok := ct.config.DefaultView.(string); ok {
 		defaultView = strings.ToLower(defaultView)
 		switch defaultView {
@@ -407,7 +412,7 @@ func (ct *Cointop) loadDefaultViewFromConfig() error {
 
 // LoadDefaultChartRangeFromConfig loads default chart range from config file to struct
 func (ct *Cointop) loadDefaultChartRangeFromConfig() error {
-	ct.debuglog("loadDefaultChartRangeFromConfig()")
+	log.Debug("loadDefaultChartRangeFromConfig()")
 	if defaultChartRange, ok := ct.config.DefaultChartRange.(string); ok {
 		// validate configured value
 		_, ok := ct.chartRangesMap[defaultChartRange]
@@ -422,7 +427,7 @@ func (ct *Cointop) loadDefaultChartRangeFromConfig() error {
 
 // LoadAPIKeysFromConfig loads API keys from config file to struct
 func (ct *Cointop) loadAPIKeysFromConfig() error {
-	ct.debuglog("loadAPIKeysFromConfig()")
+	log.Debug("loadAPIKeysFromConfig()")
 	for key, value := range ct.config.CoinMarketCap {
 		k := strings.TrimSpace(strings.ToLower(key))
 		if k == "pro_api_key" {
@@ -434,7 +439,7 @@ func (ct *Cointop) loadAPIKeysFromConfig() error {
 
 // LoadColorschemeFromConfig loads colorscheme name from config file to struct
 func (ct *Cointop) loadColorschemeFromConfig() error {
-	ct.debuglog("loadColorschemeFromConfig()")
+	log.Debug("loadColorschemeFromConfig()")
 	if colorscheme, ok := ct.config.Colorscheme.(string); ok {
 		ct.colorschemeName = colorscheme
 	}
@@ -444,7 +449,7 @@ func (ct *Cointop) loadColorschemeFromConfig() error {
 
 // LoadRefreshRateFromConfig loads refresh rate from config file to struct
 func (ct *Cointop) loadRefreshRateFromConfig() error {
-	ct.debuglog("loadRefreshRateFromConfig()")
+	log.Debug("loadRefreshRateFromConfig()")
 	if refreshRate, ok := ct.config.RefreshRate.(int64); ok {
 		ct.State.refreshRate = time.Duration(uint(refreshRate)) * time.Second
 	}
@@ -454,7 +459,7 @@ func (ct *Cointop) loadRefreshRateFromConfig() error {
 
 // LoadCacheDirFromConfig loads cache dir from config file to struct
 func (ct *Cointop) loadCacheDirFromConfig() error {
-	ct.debuglog("loadCacheDirFromConfig()")
+	log.Debug("loadCacheDirFromConfig()")
 	if cacheDir, ok := ct.config.CacheDir.(string); ok {
 		ct.State.cacheDir = pathutil.NormalizePath(cacheDir)
 	}
@@ -462,46 +467,9 @@ func (ct *Cointop) loadCacheDirFromConfig() error {
 	return nil
 }
 
-// GetColorschemeColors loads colors from colorsheme file to struct
-func (ct *Cointop) getColorschemeColors() (map[string]interface{}, error) {
-	ct.debuglog("getColorschemeColors()")
-	var colors map[string]interface{}
-	if ct.colorschemeName == "" {
-		ct.colorschemeName = DefaultColorscheme
-		if _, err := toml.Decode(DefaultColors, &colors); err != nil {
-			return nil, err
-		}
-	} else {
-		colorsDir := fmt.Sprintf("%s/colors", ct.ConfigDirPath())
-		if ct.colorsDir != "" {
-			colorsDir = pathutil.NormalizePath(ct.colorsDir)
-		}
-
-		path := fmt.Sprintf("%s/%s.toml", colorsDir, ct.colorschemeName)
-		if _, err := os.Stat(path); os.IsNotExist(err) {
-			// NOTE: case for when cointop is set as the theme but the colorscheme file doesn't exist
-			if ct.colorschemeName == "cointop" {
-				if _, err := toml.Decode(DefaultColors, &colors); err != nil {
-					return nil, err
-				}
-
-				return colors, nil
-			}
-
-			return nil, fmt.Errorf("the colorscheme file %q was not found.\n%s", path, ColorschemeHelpString())
-		}
-
-		if _, err := toml.DecodeFile(path, &colors); err != nil {
-			return nil, err
-		}
-	}
-
-	return colors, nil
-}
-
 // LoadAPIChoiceFromConfig loads API choices from config file to struct
 func (ct *Cointop) loadAPIChoiceFromConfig() error {
-	ct.debuglog("loadAPIKeysFromConfig()")
+	log.Debug("loadAPIKeysFromConfig()")
 	apiChoice, ok := ct.config.API.(string)
 	if ok {
 		apiChoice = strings.TrimSpace(strings.ToLower(apiChoice))
@@ -512,7 +480,7 @@ func (ct *Cointop) loadAPIChoiceFromConfig() error {
 
 // LoadFavoritesFromConfig loads favorites data from config file to struct
 func (ct *Cointop) loadFavoritesFromConfig() error {
-	ct.debuglog("loadFavoritesFromConfig()")
+	log.Debug("loadFavoritesFromConfig()")
 	for k, valueIfc := range ct.config.Favorites {
 		ifcs, ok := valueIfc.([]interface{})
 		if !ok {
@@ -554,7 +522,7 @@ func (ct *Cointop) loadFavoritesFromConfig() error {
 
 // LoadPortfolioFromConfig loads portfolio data from config file to struct
 func (ct *Cointop) loadPortfolioFromConfig() error {
-	ct.debuglog("loadPortfolioFromConfig()")
+	log.Debug("loadPortfolioFromConfig()")
 
 	for key, valueIfc := range ct.config.Portfolio {
 		if key == "columns" {
@@ -619,7 +587,7 @@ func (ct *Cointop) loadPortfolioFromConfig() error {
 
 // LoadPriceAlertsFromConfig loads price alerts from config file to struct
 func (ct *Cointop) loadPriceAlertsFromConfig() error {
-	ct.debuglog("loadPriceAlertsFromConfig()")
+	log.Debug("loadPriceAlertsFromConfig()")
 	priceAlertsIfc, ok := ct.config.PriceAlerts["alerts"]
 	if !ok {
 		return nil
@@ -677,6 +645,43 @@ func (ct *Cointop) loadPriceAlertsFromConfig() error {
 	return nil
 }
 
+// GetColorschemeColors loads colors from colorsheme file to struct
+func (ct *Cointop) GetColorschemeColors() (map[string]interface{}, error) {
+	log.Debug("GetColorschemeColors()")
+	var colors map[string]interface{}
+	if ct.colorschemeName == "" {
+		ct.colorschemeName = DefaultColorscheme
+		if _, err := toml.Decode(DefaultColors, &colors); err != nil {
+			return nil, err
+		}
+	} else {
+		colorsDir := fmt.Sprintf("%s/colors", ct.ConfigDirPath())
+		if ct.colorsDir != "" {
+			colorsDir = pathutil.NormalizePath(ct.colorsDir)
+		}
+
+		path := fmt.Sprintf("%s/%s.toml", colorsDir, ct.colorschemeName)
+		if _, err := os.Stat(path); os.IsNotExist(err) {
+			// NOTE: case for when cointop is set as the theme but the colorscheme file doesn't exist
+			if ct.colorschemeName == "cointop" {
+				if _, err := toml.Decode(DefaultColors, &colors); err != nil {
+					return nil, err
+				}
+
+				return colors, nil
+			}
+
+			return nil, fmt.Errorf("the colorscheme file %q was not found.\n%s", path, ColorschemeHelpString())
+		}
+
+		if _, err := toml.DecodeFile(path, &colors); err != nil {
+			return nil, err
+		}
+	}
+
+	return colors, nil
+}
+
 // InterfaceToFloat64 attempts to convert interface to float64
 func (ct *Cointop) InterfaceToFloat64(value interface{}) (float64, error) {
 	var num float64
