@@ -13,9 +13,11 @@ import (
 	"unicode/utf8"
 
 	"github.com/miguelmota/cointop/pkg/asciitable"
+	"github.com/miguelmota/cointop/pkg/eval"
 	"github.com/miguelmota/cointop/pkg/humanize"
 	"github.com/miguelmota/cointop/pkg/pad"
 	"github.com/miguelmota/cointop/pkg/table"
+	log "github.com/sirupsen/logrus"
 )
 
 // SupportedPortfolioTableHeaders are all the supported portfolio table header columns
@@ -30,6 +32,7 @@ var SupportedPortfolioTableHeaders = []string{
 	"24h_change",
 	"7d_change",
 	"30d_change",
+	"1y_change",
 	"percent_holdings",
 	"last_updated",
 }
@@ -49,6 +52,9 @@ var DefaultPortfolioTableHeaders = []string{
 	"last_updated",
 }
 
+// HiddenBalanceChars are the characters to show when hidding balances
+var HiddenBalanceChars = "********"
+
 // ValidPortfolioTableHeader returns the portfolio table headers
 func (ct *Cointop) ValidPortfolioTableHeader(name string) bool {
 	for _, v := range SupportedPortfolioTableHeaders {
@@ -68,7 +74,7 @@ func (ct *Cointop) GetPortfolioTableHeaders() []string {
 // GetPortfolioTable returns the table for displaying portfolio holdings
 func (ct *Cointop) GetPortfolioTable() *table.Table {
 	total := ct.GetPortfolioTotal()
-	maxX := ct.width()
+	maxX := ct.Width()
 	t := table.NewTable().SetWidth(maxX)
 	var rows [][]*table.RowCell
 	headers := ct.GetPortfolioTableHeaders()
@@ -139,6 +145,9 @@ func (ct *Cointop) GetPortfolioTable() *table.Table {
 					})
 			case "holdings":
 				text := strconv.FormatFloat(coin.Holdings, 'f', -1, 64)
+				if ct.State.hidePortfolioBalances {
+					text = HiddenBalanceChars
+				}
 				ct.SetTableColumnWidthFromString(header, text)
 				ct.SetTableColumnAlignLeft(header, false)
 				rowCells = append(rowCells,
@@ -151,6 +160,9 @@ func (ct *Cointop) GetPortfolioTable() *table.Table {
 					})
 			case "balance":
 				text := humanize.Monetaryf(coin.Balance, 2)
+				if ct.State.hidePortfolioBalances {
+					text = HiddenBalanceChars
+				}
 				ct.SetTableColumnWidthFromString(header, text)
 				ct.SetTableColumnAlignLeft(header, false)
 				colorBalance := ct.colorscheme.TableColumnPrice
@@ -238,12 +250,34 @@ func (ct *Cointop) GetPortfolioTable() *table.Table {
 						Color:       color30d,
 						Text:        text,
 					})
+			case "1y_change":
+				color1y := ct.colorscheme.TableColumnChange
+				if coin.PercentChange1Y > 0 {
+					color1y = ct.colorscheme.TableColumnChangeUp
+				}
+				if coin.PercentChange1Y < 0 {
+					color1y = ct.colorscheme.TableColumnChangeDown
+				}
+				text := fmt.Sprintf("%.2f%%", coin.PercentChange1Y)
+				ct.SetTableColumnWidthFromString(header, text)
+				ct.SetTableColumnAlignLeft(header, false)
+				rowCells = append(rowCells,
+					&table.RowCell{
+						LeftMargin:  leftMargin,
+						RightMargin: rightMargin,
+						LeftAlign:   false,
+						Color:       color1y,
+						Text:        text,
+					})
 			case "percent_holdings":
 				percentHoldings := (coin.Balance / total) * 1e2
 				if math.IsNaN(percentHoldings) {
 					percentHoldings = 0
 				}
 				text := fmt.Sprintf("%.2f%%", percentHoldings)
+				if ct.State.hidePortfolioBalances {
+					text = HiddenBalanceChars
+				}
 				ct.SetTableColumnWidthFromString(header, text)
 				ct.SetTableColumnAlignLeft(header, false)
 				rowCells = append(rowCells,
@@ -285,7 +319,7 @@ func (ct *Cointop) GetPortfolioTable() *table.Table {
 
 // TogglePortfolio toggles the portfolio view
 func (ct *Cointop) TogglePortfolio() error {
-	ct.debuglog("togglePortfolio()")
+	log.Debug("TogglePortfolio()")
 	ct.ToggleSelectedView(PortfolioView)
 	go ct.UpdateChart()
 	go ct.UpdateTable()
@@ -294,7 +328,7 @@ func (ct *Cointop) TogglePortfolio() error {
 
 // ToggleShowPortfolio shows the portfolio view
 func (ct *Cointop) ToggleShowPortfolio() error {
-	ct.debuglog("toggleShowPortfolio()")
+	log.Debug("ToggleShowPortfolio()")
 	ct.SetSelectedView(PortfolioView)
 	go ct.UpdateChart()
 	go ct.UpdateTable()
@@ -303,7 +337,7 @@ func (ct *Cointop) ToggleShowPortfolio() error {
 
 // TogglePortfolioUpdateMenu toggles the portfolio update menu
 func (ct *Cointop) TogglePortfolioUpdateMenu() error {
-	ct.debuglog("togglePortfolioUpdateMenu()")
+	log.Debug("TogglePortfolioUpdateMenu()")
 	if ct.IsPriceAlertsVisible() {
 		return ct.ShowPriceAlertsUpdateMenu()
 	}
@@ -323,11 +357,11 @@ func (ct *Cointop) CoinHoldings(coin *Coin) float64 {
 
 // UpdatePortfolioUpdateMenu updates the portfolio update menu view
 func (ct *Cointop) UpdatePortfolioUpdateMenu() error {
-	ct.debuglog("updatePortfolioUpdateMenu()")
+	log.Debug("UpdatePortfolioUpdateMenu()")
 	coin := ct.HighlightedRowCoin()
 	exists := ct.PortfolioEntryExists(coin)
 	value := strconv.FormatFloat(ct.CoinHoldings(coin), 'f', -1, 64)
-	ct.debuglog("holdings %v", value)
+	log.Debugf("UpdatePortfolioUpdateMenu() holdings %v", value)
 	var mode string
 	var current string
 	var submitText string
@@ -339,7 +373,7 @@ func (ct *Cointop) UpdatePortfolioUpdateMenu() error {
 		mode = "Add"
 		submitText = "Add"
 	}
-	header := ct.colorscheme.MenuHeader(fmt.Sprintf(" %s Portfolio Entry %s\n\n", mode, pad.Left("[q] close ", ct.width()-25, " ")))
+	header := ct.colorscheme.MenuHeader(fmt.Sprintf(" %s Portfolio Entry %s\n\n", mode, pad.Left("[q] close ", ct.Width()-25, " ")))
 	label := fmt.Sprintf(" Enter holdings for %s %s", ct.colorscheme.MenuLabel(coin.Name), current)
 	content := fmt.Sprintf("%s\n%s\n\n%s%s\n\n\n [Enter] %s    [ESC] Cancel", header, label, strings.Repeat(" ", 29), coin.Symbol, submitText)
 
@@ -355,7 +389,7 @@ func (ct *Cointop) UpdatePortfolioUpdateMenu() error {
 
 // ShowPortfolioUpdateMenu shows the portfolio update menu
 func (ct *Cointop) ShowPortfolioUpdateMenu() error {
-	ct.debuglog("showPortfolioUpdateMenu()")
+	log.Debug("ShowPortfolioUpdateMenu()")
 
 	// TODO: separation of concerns
 	if ct.IsPriceAlertsVisible() {
@@ -379,7 +413,7 @@ func (ct *Cointop) ShowPortfolioUpdateMenu() error {
 
 // HidePortfolioUpdateMenu hides the portfolio update menu
 func (ct *Cointop) HidePortfolioUpdateMenu() error {
-	ct.debuglog("hidePortfolioUpdateMenu()")
+	log.Debug("HidePortfolioUpdateMenu()")
 	ct.State.portfolioUpdateMenuVisible = false
 	ct.ui.SetViewOnBottom(ct.Views.Menu)
 	ct.ui.SetViewOnBottom(ct.Views.Input)
@@ -397,7 +431,7 @@ func (ct *Cointop) HidePortfolioUpdateMenu() error {
 
 // SetPortfolioHoldings sets portfolio entry holdings from inputed value
 func (ct *Cointop) SetPortfolioHoldings() error {
-	ct.debuglog("setPortfolioHoldings()")
+	log.Debug("SetPortfolioHoldings()")
 	defer ct.HidePortfolioUpdateMenu()
 	coin := ct.HighlightedRowCoin()
 	if coin == nil {
@@ -414,16 +448,13 @@ func (ct *Cointop) SetPortfolioHoldings() error {
 		return nil
 	}
 
-	value := normalizeFloatString(string(b), true)
-	shouldDelete := value == ""
-	var holdings float64
-
-	if !shouldDelete {
-		holdings, err = strconv.ParseFloat(value, 64)
-		if err != nil {
-			return err
-		}
+	input := string(b[:n])
+	holdings, err := eval.EvaluateExpressionToFloat64(input, coin)
+	if err != nil {
+		// leave value as is if expression can't be evaluated
+		return nil
 	}
+	shouldDelete := holdings == 0
 
 	idx := ct.GetPortfolioCoinIndex(coin)
 	if err := ct.SetPortfolioEntry(coin.Name, holdings); err != nil {
@@ -451,7 +482,7 @@ func (ct *Cointop) SetPortfolioHoldings() error {
 
 // PortfolioEntry returns a portfolio entry
 func (ct *Cointop) PortfolioEntry(c *Coin) (*PortfolioEntry, bool) {
-	//ct.debuglog("portfolioEntry()") // too many
+	//log.Debug("PortfolioEntry()") // too many
 	if c == nil {
 		return &PortfolioEntry{}, true
 	}
@@ -477,7 +508,7 @@ func (ct *Cointop) PortfolioEntry(c *Coin) (*PortfolioEntry, bool) {
 
 // SetPortfolioEntry sets a portfolio entry
 func (ct *Cointop) SetPortfolioEntry(coin string, holdings float64) error {
-	ct.debuglog("setPortfolioEntry()")
+	log.Debug("SetPortfolioEntry()")
 	ic, _ := ct.State.allCoinsSlugMap.Load(strings.ToLower(coin))
 	c, _ := ic.(*Coin)
 	p, isNew := ct.PortfolioEntry(c)
@@ -500,7 +531,7 @@ func (ct *Cointop) SetPortfolioEntry(coin string, holdings float64) error {
 
 // RemovePortfolioEntry removes a portfolio entry
 func (ct *Cointop) RemovePortfolioEntry(coin string) error {
-	ct.debuglog("removePortfolioEntry()")
+	log.Debug("RemovePortfolioEntry()")
 	delete(ct.State.portfolio.Entries, strings.ToLower(coin))
 	if err := ct.Save(); err != nil {
 		return err
@@ -510,20 +541,20 @@ func (ct *Cointop) RemovePortfolioEntry(coin string) error {
 
 // PortfolioEntryExists returns true if portfolio entry exists
 func (ct *Cointop) PortfolioEntryExists(c *Coin) bool {
-	ct.debuglog("portfolioEntryExists()")
+	log.Debug("PortfolioEntryExists()")
 	_, isNew := ct.PortfolioEntry(c)
 	return !isNew
 }
 
 // PortfolioEntriesCount returns the count of portfolio entries
 func (ct *Cointop) PortfolioEntriesCount() int {
-	ct.debuglog("portfolioEntriesCount()")
+	log.Debug("PortfolioEntriesCount()")
 	return len(ct.State.portfolio.Entries)
 }
 
 // GetPortfolioSlice returns portfolio entries as a slice
 func (ct *Cointop) GetPortfolioSlice() []*Coin {
-	ct.debuglog("getPortfolioSlice()")
+	log.Debug("GetPortfolioSlice()")
 	sliced := []*Coin{}
 	if ct.PortfolioEntriesCount() == 0 {
 		return sliced
@@ -577,7 +608,7 @@ OUTER:
 
 // GetPortfolioTotal returns the total balance of portfolio entries
 func (ct *Cointop) GetPortfolioTotal() float64 {
-	ct.debuglog("getPortfolioTotal()")
+	log.Debug("GetPortfolioTotal()")
 	portfolio := ct.GetPortfolioSlice()
 	var total float64
 	for _, p := range portfolio {
@@ -588,7 +619,7 @@ func (ct *Cointop) GetPortfolioTotal() float64 {
 
 // RefreshPortfolioCoins refreshes portfolio entry coin data
 func (ct *Cointop) RefreshPortfolioCoins() error {
-	ct.debuglog("refreshPortfolioCoins()")
+	log.Debug("RefreshPortfolioCoins()")
 	holdings := ct.GetPortfolioSlice()
 	holdingCoins := make([]string, len(holdings))
 	for i, entry := range holdings {
@@ -615,6 +646,7 @@ type TablePrintOptions struct {
 	Convert          string
 	NoHeader         bool
 	PercentChange24H bool
+	HideBalances     bool
 }
 
 // outputFormats is list of valid output formats
@@ -636,7 +668,7 @@ var portfolioColumns = map[string]bool{
 
 // PrintHoldingsTable prints the holdings in an ASCII table
 func (ct *Cointop) PrintHoldingsTable(options *TablePrintOptions) error {
-	ct.debuglog("printHoldingsTable()")
+	log.Debug("PrintHoldingsTable()")
 	if options == nil {
 		options = &TablePrintOptions{}
 	}
@@ -655,6 +687,7 @@ func (ct *Cointop) PrintHoldingsTable(options *TablePrintOptions) error {
 	filterCols := options.Cols
 	holdings := ct.GetPortfolioSlice()
 	noHeader := options.NoHeader
+	hideBalances := options.HideBalances
 
 	if format == "" {
 		format = "table"
@@ -746,12 +779,18 @@ func (ct *Cointop) PrintHoldingsTable(options *TablePrintOptions) error {
 				} else {
 					item[i] = strconv.FormatFloat(entry.Holdings, 'f', -1, 64)
 				}
+				if hideBalances {
+					item[i] = HiddenBalanceChars
+				}
 			case "balance":
 				if humanReadable {
 					item[i] = fmt.Sprintf("%s%s", symbol, humanize.Monetaryf(entry.Balance, 2))
 				} else {
 					item[i] = strconv.FormatFloat(entry.Balance, 'f', -1, 64)
 				}
+				if hideBalances {
+					item[i] = HiddenBalanceChars
+				}
 			case "24h%":
 				if humanReadable {
 					item[i] = fmt.Sprintf("%s%%", humanize.Numericf(entry.PercentChange24H, 2))
@@ -764,6 +803,9 @@ func (ct *Cointop) PrintHoldingsTable(options *TablePrintOptions) error {
 				} else {
 					item[i] = fmt.Sprintf("%.2f", percentHoldings)
 				}
+				if hideBalances {
+					item[i] = HiddenBalanceChars
+				}
 			}
 		}
 		records[i] = item
@@ -835,7 +877,7 @@ func (ct *Cointop) PrintHoldingsTable(options *TablePrintOptions) error {
 
 // PrintHoldingsTotal prints the total holdings amount
 func (ct *Cointop) PrintHoldingsTotal(options *TablePrintOptions) error {
-	ct.debuglog("PrintHoldingsTotal()")
+	log.Debug("PrintHoldingsTotal()")
 	if options == nil {
 		options = &TablePrintOptions{}
 	}
@@ -909,7 +951,7 @@ func (ct *Cointop) PrintHoldingsTotal(options *TablePrintOptions) error {
 
 // PrintHoldings24HChange prints the total holdings amount
 func (ct *Cointop) PrintHoldings24HChange(options *TablePrintOptions) error {
-	ct.debuglog("PrintHoldings24HChange()")
+	log.Debug("PrintHoldings24HChange()")
 	if options == nil {
 		options = &TablePrintOptions{}
 	}
@@ -1015,3 +1057,14 @@ func (ct *Cointop) IsPortfolioVisible() bool {
 func (ct *Cointop) PortfolioLen() int {
 	return len(ct.GetPortfolioSlice())
 }
+
+// TogglePortfolioBalances toggles hide/show portfolio balances. Useful for keeping balances secret when sharing screen or taking screenshots.
+func (ct *Cointop) TogglePortfolioBalances() error {
+	ct.State.hidePortfolioBalances = !ct.State.hidePortfolioBalances
+	ct.UpdateUI(func() error {
+		go ct.UpdateChart()
+		go ct.UpdateTable()
+		return nil
+	})
+	return nil
+}
