@@ -12,6 +12,7 @@ import (
 	"github.com/miguelmota/cointop/pkg/notifier"
 	"github.com/miguelmota/cointop/pkg/pad"
 	"github.com/miguelmota/cointop/pkg/table"
+	log "github.com/sirupsen/logrus"
 )
 
 // GetPriceAlertsTableHeaders returns the alerts table headers
@@ -42,8 +43,8 @@ var PriceAlertFrequencyMap = map[string]bool{
 
 // GetPriceAlertsTable returns the table for displaying alerts
 func (ct *Cointop) GetPriceAlertsTable() *table.Table {
-	ct.debuglog("getPriceAlertsTable()")
-	maxX := ct.width()
+	log.Debug("GetPriceAlertsTable()")
+	maxX := ct.Width()
 	t := table.NewTable().SetWidth(maxX)
 	var rows [][]*table.RowCell
 	headers := ct.GetPriceAlertsTableHeaders()
@@ -145,7 +146,7 @@ func (ct *Cointop) GetPriceAlertsTable() *table.Table {
 
 // TogglePriceAlerts toggles the price alerts view
 func (ct *Cointop) TogglePriceAlerts() error {
-	ct.debuglog("togglePriceAlerts()")
+	log.Debug("TogglePriceAlerts()")
 	ct.ToggleSelectedView(PriceAlertsView)
 	ct.NavigateFirstLine()
 	go ct.UpdateTable()
@@ -159,7 +160,7 @@ func (ct *Cointop) IsPriceAlertsVisible() bool {
 
 // PriceAlertWatcher starts the price alert watcher
 func (ct *Cointop) PriceAlertWatcher() error {
-	ct.debuglog("priceAlertWatcher()")
+	log.Debug("PriceAlertWatcher()")
 	alerts := ct.State.priceAlerts.Entries
 	ticker := time.NewTicker(5 * time.Second)
 	for range ticker.C {
@@ -175,7 +176,7 @@ func (ct *Cointop) PriceAlertWatcher() error {
 
 // CheckPriceAlert checks the price alert
 func (ct *Cointop) CheckPriceAlert(alert *PriceAlert) error {
-	ct.debuglog("checkPriceAlert()")
+	log.Debug("CheckPriceAlert()")
 	if alert.Expired {
 		return nil
 	}
@@ -227,7 +228,7 @@ func (ct *Cointop) CheckPriceAlert(alert *PriceAlert) error {
 
 // UpdatePriceAlertsUpdateMenu updates the alerts update menu view
 func (ct *Cointop) UpdatePriceAlertsUpdateMenu(isNew bool, coin *Coin) error {
-	ct.debuglog("updatePriceAlertsUpdateMenu()")
+	log.Debug("UpdatePriceAlertsUpdateMenu()")
 
 	isEdit := false
 	var value string
@@ -266,7 +267,7 @@ func (ct *Cointop) UpdatePriceAlertsUpdateMenu(isNew bool, coin *Coin) error {
 		mode = "Edit"
 		current = fmt.Sprintf("(current %s%s)", ct.CurrencySymbol(), currentPrice)
 		submitText = "Set"
-		offset = ct.width() - 21
+		offset = ct.Width() - 21
 	} else {
 		if coin == nil {
 			coin = ct.HighlightedRowCoin()
@@ -275,7 +276,7 @@ func (ct *Cointop) UpdatePriceAlertsUpdateMenu(isNew bool, coin *Coin) error {
 		value = fmt.Sprintf("> %s", currentPrice)
 		mode = "Create"
 		submitText = "Create"
-		offset = ct.width() - 23
+		offset = ct.Width() - 23
 	}
 	header := ct.colorscheme.MenuHeader(fmt.Sprintf(" %s Alert Entry %s\n\n", mode, pad.Left("[q] close ", offset, " ")))
 	label := fmt.Sprintf(" Enter target price for %s %s", ct.colorscheme.MenuLabel(coin.Name), current)
@@ -293,7 +294,7 @@ func (ct *Cointop) UpdatePriceAlertsUpdateMenu(isNew bool, coin *Coin) error {
 
 // ShowPriceAlertsAddMenu shows the alert add menu
 func (ct *Cointop) ShowPriceAlertsAddMenu() error {
-	ct.debuglog("showPriceAlertsAddMenu()")
+	log.Debug("ShowPriceAlertsAddMenu()")
 	coin := ct.HighlightedRowCoin()
 	ct.SetSelectedView(PriceAlertsView)
 	ct.UpdatePriceAlertsUpdateMenu(true, coin)
@@ -306,7 +307,7 @@ func (ct *Cointop) ShowPriceAlertsAddMenu() error {
 
 // ShowPriceAlertsUpdateMenu shows the alerts update menu
 func (ct *Cointop) ShowPriceAlertsUpdateMenu() error {
-	ct.debuglog("showPriceAlertsUpdateMenu()")
+	log.Debug("ShowPriceAlertsUpdateMenu()")
 	coin := ct.HighlightedRowCoin()
 	ct.SetSelectedView(PriceAlertsView)
 	ct.UpdatePriceAlertsUpdateMenu(false, coin)
@@ -319,7 +320,7 @@ func (ct *Cointop) ShowPriceAlertsUpdateMenu() error {
 
 // HidePriceAlertsUpdateMenu hides the alerts update menu
 func (ct *Cointop) HidePriceAlertsUpdateMenu() error {
-	ct.debuglog("hidePriceAlertsUpdateMenu()")
+	log.Debug("HidePriceAlertsUpdateMenu()")
 	ct.ui.SetViewOnBottom(ct.Views.Menu)
 	ct.ui.SetViewOnBottom(ct.Views.Input)
 	ct.ui.SetCursor(false)
@@ -345,7 +346,7 @@ func (ct *Cointop) EnterKeyPressHandler() error {
 
 // CreatePriceAlert sets price from inputed value
 func (ct *Cointop) CreatePriceAlert() error {
-	ct.debuglog("createPriceAlert()")
+	log.Debug("CreatePriceAlert()")
 	defer ct.HidePriceAlertsUpdateMenu()
 
 	isNew := ct.State.priceAlertNewID != ""
@@ -436,7 +437,7 @@ func (ct *Cointop) ParsePriceAlertInput(value string) (string, float64, error) {
 
 // SetPriceAlert sets a price alert
 func (ct *Cointop) SetPriceAlert(coinName string, operator string, targetPrice float64) error {
-	ct.debuglog("setPriceAlert()")
+	log.Debug("SetPriceAlert()")
 
 	if operator == "" {
 		operator = "="
@@ -474,7 +475,7 @@ func (ct *Cointop) SetPriceAlert(coinName string, operator string, targetPrice f
 
 // RemovePriceAlert removes a price alert entry
 func (ct *Cointop) RemovePriceAlert(id string) error {
-	ct.debuglog("removePriceAlert()")
+	log.Debug("RemovePriceAlert()")
 	for i, entry := range ct.State.priceAlerts.Entries {
 		if entry.ID == ct.State.priceAlertEditID {
 			ct.State.priceAlerts.Entries = append(ct.State.priceAlerts.Entries[:i], ct.State.priceAlerts.Entries[i+1:]...)
