@@ -3,11 +3,13 @@ package cointop
 import (
 	"strings"
 	"time"
+
+	log "github.com/sirupsen/logrus"
 )
 
 // Refresh triggers a force refresh of coin data
 func (ct *Cointop) Refresh() error {
-	ct.debuglog("refresh()")
+	log.Debug("Refresh()")
 	go func() {
 		<-ct.limiter
 		ct.forceRefresh <- true
@@ -17,7 +19,7 @@ func (ct *Cointop) Refresh() error {
 
 // RefreshAll triggers a force refresh of all data
 func (ct *Cointop) RefreshAll() error {
-	ct.debuglog("refreshAll()")
+	log.Debug("RefreshAll()")
 	ct.refreshMux.Lock()
 	defer ct.refreshMux.Unlock()
 	ct.setRefreshStatus()
@@ -33,7 +35,7 @@ func (ct *Cointop) RefreshAll() error {
 
 // SetRefreshStatus sets the refresh ticker
 func (ct *Cointop) setRefreshStatus() {
-	ct.debuglog("setRefreshStatus()")
+	log.Debug("setRefreshStatus()")
 	go func() {
 		ct.loadingTicks("refreshing", 900)
 		ct.RowChanged()
@@ -42,7 +44,7 @@ func (ct *Cointop) setRefreshStatus() {
 
 // LoadingTicks sets the loading ticking dots
 func (ct *Cointop) loadingTicks(s string, t int) {
-	ct.debuglog("loadingTicks()")
+	log.Debug("loadingTicks()")
 	interval := 150
 	k := 0
 	for i := 0; i < (t / interval); i++ {
@@ -57,7 +59,7 @@ func (ct *Cointop) loadingTicks(s string, t int) {
 
 // intervalFetchData does a force refresh at every interval
 func (ct *Cointop) intervalFetchData() {
-	ct.debuglog("intervalFetchData()")
+	log.Debug("intervalFetchData()")
 	go func() {
 		for {
 			select {
