@@ -1,8 +1,10 @@
 package cointop
 
+import log "github.com/sirupsen/logrus"
+
 // Save saves the cointop settings to the config file
 func (ct *Cointop) Save() error {
-	ct.debuglog("Save()")
+	log.Debug("Save()")
 	ct.SetSavingStatus()
 	if err := ct.SaveConfig(); err != nil {
 		return err
@@ -15,7 +17,7 @@ func (ct *Cointop) Save() error {
 
 // SetSavingStatus sets the saving indicator in the statusbar
 func (ct *Cointop) SetSavingStatus() {
-	ct.debuglog("SetSavingStatus()")
+	log.Debug("SetSavingStatus()")
 	if ct.g == nil {
 		return
 	}
